package net.wanji.utc.service.control.impl;

import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONObject;
import com.google.common.collect.Lists;
import com.hikvision.artemis.sdk.ArtemisHttpUtil;
import com.hikvision.artemis.sdk.config.ArtemisConfig;
import lombok.extern.slf4j.Slf4j;
import net.wanji.common.framework.rest.JsonViewObject;
import net.wanji.utc.common.baseentity.BaseCrossInfo;
import net.wanji.utc.common.exception.ControlException;
import net.wanji.utc.common.typeenum.BasicEnum;
import net.wanji.utc.dto.hk.DownloadPlanSpandsDTO;
import net.wanji.utc.dto.hk.DownloadScheduleDTO;
import net.wanji.utc.dto.hk.DownloadTimeSpandsDTO;
import net.wanji.utc.mapper.CrossInfoMapper;
import net.wanji.utc.mapper.CrossPhaseMapper;
import net.wanji.utc.mapper.ManufacturerInfoMapper;
import net.wanji.utc.po.CrossInfoPO;
import net.wanji.utc.po.CrossPhasePO;
import net.wanji.utc.po.ManufacturerInfoPO;
import net.wanji.utc.po.hk.response.HKResponse;
import net.wanji.utc.service.control.ControlCommandService;
import net.wanji.utc.service.runninginfo.HkLightsStatusService;
import net.wanji.utc.service.runninginfo.impl.HkLightsStatusServiceImpl;
import net.wanji.utc.util.FieldUtil;
import net.wanji.utc.util.PathUtil;
import net.wanji.utc.util.StringUtils;
import net.wanji.utc.vo.*;
import org.springframework.stereotype.Service;
import org.springframework.util.CollectionUtils;

import javax.annotation.Resource;
import java.util.*;
import java.util.stream.Collectors;

import static net.wanji.utc.common.ResultEnum.BODY_NOT_MATCH;
import static net.wanji.utc.common.constant.Constants.*;

/**
 * @author wuxiaokai
 * @date 2022/11/21 9:51:47
 */
@Slf4j
@Service("hkControlCommandService")
public class HKControlCommandServiceImpl implements ControlCommandService {

    @Resource
    private HkLightsStatusService hkLightsStatusService;
    @Resource
    private ArtemisConfig artemisConfig;
    @Resource
    private CrossPhaseMapper crossPhaseMapper;
    @Resource
    private CrossInfoMapper crossInfoMapper;
    @Resource
    private ManufacturerInfoMapper manufacturerInfoMapper;

    @Override
    public JsonViewObject schemeSend(SchemeSendVO schemeSendVO) throws Exception {
        JsonViewObject jsonViewObject = JsonViewObject.newInstance();
        CrossInfoPO crossInfoPO = crossInfoMapper.selectByPrimaryKey(schemeSendVO.getCrossCode());
        if (Objects.isNull(crossInfoPO)) {
            return jsonViewObject.fail("当前路口编号有误，路口信息不存在");
        }
        // 1、组装参数, 下发海康信号机
        DownloadPlanSpandsDTO dto = new DownloadPlanSpandsDTO();
        // 将路口code转换为信号机code
        dto.setCrossCode(crossInfoPO.getCode());
        List<DownloadPlanSpandsDTO.Pattern> patternList = new ArrayList<>();
        schemeSendVO.getPatternList().forEach(pattern -> {
            DownloadPlanSpandsDTO.Pattern pattern1 = new DownloadPlanSpandsDTO.Pattern();
            pattern1.setPatternNo(pattern.getPatternNo());
            pattern1.setPatternName(pattern.getPatternName());
            pattern1.setCoordPhase(pattern.getCoordPhase());
            pattern1.setOffset(pattern.getOffset());
            pattern1.setCycle(pattern.getCycle());
            List<DownloadPlanSpandsDTO.Pattern.Ring> rings = new ArrayList<>();
            pattern.getRings().forEach(ring -> {
                DownloadPlanSpandsDTO.Pattern.Ring ring1 = new DownloadPlanSpandsDTO.Pattern.Ring();
                ring1.setRingNo(ring.getRingNo());
                List<DownloadPlanSpandsDTO.Pattern.Ring.Phase> phaseList = new ArrayList<>();
                ring.getPhaseList().forEach(phase -> {
                    DownloadPlanSpandsDTO.Pattern.Ring.Phase phase1 = new DownloadPlanSpandsDTO.Pattern.Ring.Phase();
                    phase1.setPhaseNo(phase.getPhaseNo());
                    phase1.setPhaseName(phase.getPhaseName());
                    phase1.setPhaseLength(phase.getPhaseTime());
                    phase1.setPhaseSequence(phase.getSort());
                    phase1.setLanes(Lists.newArrayList());
                    phaseList.add(phase1);
                });
                ring1.setPhaseList(phaseList);
                rings.add(ring1);
            });
            pattern1.setRings(rings);
            patternList.add(pattern1);
        });
        dto.setPatternList(patternList);
        // 下发信号机方案
//        Map<String, Object> fieldMap = FieldUtil.fieldMethod(dto);
        Map<String, String> path = PathUtil.getPathMapByApiCode("downloadPlanSpands");
        String strResult = ArtemisHttpUtil.doPostStringArtemis(artemisConfig, path, JSONObject.toJSONString(dto), null, null, "application/json", null);
        HKResponse hkResponse = JSONObject.parseObject(strResult, HKResponse.class);
        if (Objects.nonNull(hkResponse) && Objects.equals(HK_SUCCESS_STRING_CODE, hkResponse.getCode())) {
            return jsonViewObject.success("海康下发信号机方案成功");
        }
        return jsonViewObject.fail("海康下发信号机方案失败，".concat(hkResponse.getMsg()));
    }

    @Override
    public JsonViewObject planSend(PlanSendVO planSendVO) throws Exception {
        JsonViewObject jsonViewObject = JsonViewObject.newInstance();
        CrossInfoPO crossInfoPO = crossInfoMapper.selectByPrimaryKey(planSendVO.getCrossCode());
        if (Objects.isNull(crossInfoPO)) {
            return jsonViewObject.fail("当前路口编号有误，路口信息不存在");
        }
        // 1、下发信号机计划拼接参数
        DownloadTimeSpandsDTO downloadTimeSpandsDTO = new DownloadTimeSpandsDTO();
        List<DownloadTimeSpandsDTO.Data> dataList = new ArrayList<>();
        DownloadTimeSpandsDTO.Data data = new DownloadTimeSpandsDTO.Data();
        data.setCrossCode(crossInfoPO.getCode());
        List<DownloadTimeSpandsDTO.Data.Plan> planList = new ArrayList<>();
        planSendVO.getPlanList().forEach(plan -> {
            DownloadTimeSpandsDTO.Data.Plan plan1 = new DownloadTimeSpandsDTO.Data.Plan();
            plan1.setPlanNo(plan.getPlanNo());
            List<DownloadTimeSpandsDTO.Data.Plan.Section> sectionList = new ArrayList<>();
            plan.getSectionList().forEach(section -> {
                DownloadTimeSpandsDTO.Data.Plan.Section section1 = new DownloadTimeSpandsDTO.Data.Plan.Section();
                section1.setTimeSecNo(section.getSectionNo());
                section1.setPatternNo(section.getPatternNo());
                String controtype = "4";
                if (StringUtils.isNotBlank(section.getControlMode()) && !StringUtils.equals("1", section.getControlMode())) {
                    for (Map.Entry<String, String> item : HkLightsStatusServiceImpl.runModeParseMap.entrySet()) {
                        if (StringUtils.equals(item.getValue(), section.getControlMode())) {
                            controtype = item.getKey();
                            break;
                        }
                    }
                }
                section1.setControlType(controtype);
                section1.setBeginTime(section.getBeginTime());
                sectionList.add(section1);
            });
            plan1.setSectionList(sectionList);
            planList.add(plan1);
        });
        data.setPlanList(planList);
        dataList.add(data);
        downloadTimeSpandsDTO.setData(dataList);

        // 1、下发信号机计划
        Map<String, Object> fieldMap = FieldUtil.fieldMethod(downloadTimeSpandsDTO);
        Map<String, String> path = PathUtil.getPathMapByApiCode("downloadTimeSpands");
        String strResult = ArtemisHttpUtil.doPostStringArtemis(artemisConfig, path, JSON.toJSONString(fieldMap), null, null, "application/json", null);
        HKResponse hkResponse = JSONObject.parseObject(strResult, HKResponse.class);
        if (Objects.nonNull(hkResponse) && Objects.equals(HK_SUCCESS_STRING_CODE, String.valueOf(hkResponse.getCode()))) {
            return jsonViewObject.success("海康下发信号机计划成功");
        }
        return jsonViewObject.fail("海康下发信号机计划失败，".concat(hkResponse.getMsg()));
    }

    @Override
    public JsonViewObject scheduleSend(ScheduleSendVO param) throws Exception {
        JsonViewObject jsonViewObject = JsonViewObject.newInstance();
        CrossInfoPO crossInfoPO = crossInfoMapper.selectByPrimaryKey(param.getCrossCode());
        if (Objects.isNull(crossInfoPO)) {
            return jsonViewObject.fail("当前路口编号有误，路口信息不存在");
        }
        String signalCode = crossInfoPO.getCode();
        // 下发信号机日期拼接参数
        DownloadScheduleDTO dto = new DownloadScheduleDTO();
        dto.setCrossCode(signalCode);
        List<DownloadScheduleDTO.Schedule> schedules = new ArrayList<>();
        for (ScheduleSendVO.Schedule schedule : param.getSchedules()) {
            List<ScheduleSendVO.Schedule.Week> scheduleWeeks = schedule.getWeeks();
            List<ScheduleSendVO.Schedule.SpecialDay> scheduleDays = schedule.getSpecialDays();
            if (null != scheduleWeeks && scheduleWeeks.size() > 0) {
                // 去重，获取所有的运行方案号
                Set<Integer> planNos = new HashSet<>();
                scheduleWeeks.forEach(week -> planNos.add(week.getPlanNo()));
                if (null != scheduleDays && scheduleDays.size() > 0) {
                    scheduleDays.forEach(specialDay -> planNos.add(specialDay.getPlanNo()));
                }
                for (Integer planNo : planNos) {
                    DownloadScheduleDTO.Schedule schedule1 = new DownloadScheduleDTO.Schedule();
                    // 0 说明 dates 内的日期是日期集合，1 说明是dates 内的数据是日期范围
                    schedule1.setIsPeriod(0);
                    // 特殊日期列表
                    List<String> dates = new ArrayList<>();
                    schedule.getSpecialDays().forEach(specialDay -> {
                        if (specialDay.getPlanNo().equals(planNo)) {
                            dates.add(specialDay.getDateStr());
                        }
                    });
                    schedule1.setDates(dates);
                    // 星期列表
                    List<Integer> weeks = new ArrayList<>();
                    schedule.getWeeks().forEach(week -> {
                        if (week.getPlanNo().equals(planNo)) {
                            weeks.add(week.getWeekNum());
                        }
                    });
                    schedule1.setWeeks(weeks);
                    schedule1.setPlanNo(planNo);
                    schedule1.setScheduleId(Integer.valueOf(schedule.getScheduleNo()));
                    schedules.add(schedule1);
                }
            }
        }
        dto.setSchedules(schedules);
        // 2、下发时间表
        Map<String, Object> fieldMap = FieldUtil.fieldMethod(dto);
        for (DownloadScheduleDTO.Schedule schedule : dto.getSchedules()) {
            List<Map<String, Object>> mapSchedules = (List<Map<String, Object>>) fieldMap.get("schedules");
            for (Map<String, Object> mapSchedule : mapSchedules) {
                if (mapSchedule.get("planNo").equals(schedule.getPlanNo())) {
                    mapSchedule.put("weeks", schedule.getWeeks());
                    mapSchedule.put("dates", schedule.getDates());
                    break;
                }
            }
        }
        Map<String, String> downloadSchedulePath = PathUtil.getPathMapByApiCode("downloadSchedule");
        String updateResult = ArtemisHttpUtil.doPostStringArtemis(artemisConfig, downloadSchedulePath, JSON.toJSONString(fieldMap), null, null, "application/json", null);
        HKResponse hkResponse = JSONObject.parseObject(updateResult, HKResponse.class);
        if (Objects.nonNull(hkResponse) && Objects.equals(HK_SUCCESS_STRING_CODE, hkResponse.getCode())) {
            return jsonViewObject.success("时间表下发成功");
        }

        return jsonViewObject.fail("时间表下发失败".concat(hkResponse.getMsg()));
    }

    @Override
    public JsonViewObject lockControl(ControlCommandVO commandVO) throws Exception {
        JsonViewObject jsonViewObject = JsonViewObject.newInstance();
        CrossInfoPO crossInfoPO = crossInfoMapper.selectByPrimaryKey(commandVO.getCrossCode());
        if (Objects.isNull(crossInfoPO)) {
            return jsonViewObject.fail("当前路口编号有误，路口信息不存在");
        }
        String signalCode = crossInfoPO.getCode();
        if (commandVO.getCommand().equals(TRUE)) {
            Map<String, Object> param = new HashMap<String, Object>();
            param.put("crossCode", signalCode);
            param.put("controlType", LOCK_RUNNING_CONTROL);

            // 获取某一路口下海康相位和车道关系
            //Map<Integer, JSONArray> laneArrayMap = getPhaseRelationLanes(commandVO.getCrossCode());
            Map<Integer, JSONArray> laneArrayMap = getPhaseRelationLanes(signalCode);

            // 控制命令为灯态锁定时，设置相关车道参数信息
            //List<SignalRunring> runrings = getSignalInfoVos(commandVO.getCrossCode()).get(0).getRunrings();
            // HK 为单环
            // 获取当前运行方案的相位id
            Integer phaseId;
            List<Map<String, Object>> laneList = new ArrayList<>();
            if (CollectionUtils.isEmpty(commandVO.getPhaseList())) {
                LightsStatusVO statusVO = getSignalInfoVos(signalCode).get(0);
                phaseId = Integer.valueOf(statusVO.getPhaseId());
                JSONArray jsonArray = laneArrayMap.get(phaseId);
                for (int i = 0; i < jsonArray.size(); i++) {
                    JSONObject jsonObject = jsonArray.getJSONObject(i);
                    Map<String, Object> laneMap = new HashMap<>();
                    laneMap.put("laneNo", jsonObject.getInteger("laneNo"));
                    laneMap.put("turn", jsonObject.getInteger("turn"));
                    laneMap.put("direction", jsonObject.getInteger("direction"));
                    laneList.add(laneMap);
                }
                param.put("laneInfos", laneList);
                param.put("controlNo", 0);
                // 控制时长，单位 s，0 则持续控制
                param.put("duration", Objects.isNull(commandVO.getDuration()) || commandVO.getDuration() == 0 ? 999 : commandVO.getDuration());
            } else {
                List<Integer> phaseList = commandVO.getPhaseList();
                for (Integer phaseNo : phaseList) {
                    phaseId = phaseNo;
                    JSONArray jsonArray = laneArrayMap.get(phaseId);
                    for (int i = 0; i < jsonArray.size(); i++) {
                        JSONObject jsonObject = jsonArray.getJSONObject(i);
                        Map<String, Object> laneMap = new HashMap<>();
                        laneMap.put("laneNo", jsonObject.getInteger("laneNo"));
                        laneMap.put("turn", jsonObject.getInteger("turn"));
                        laneMap.put("direction", jsonObject.getInteger("direction"));
                        laneList.add(laneMap);
                    }
                }
            }
            param.put("laneInfos", laneList);
            param.put("controlNo", 0);
            // 控制时长，单位 s，0 则持续控制
            param.put("duration", Objects.isNull(commandVO.getDuration()) || commandVO.getDuration() == 0 ? 999 : commandVO.getDuration());

            String strResult = ArtemisHttpUtil.doPostStringArtemis(artemisConfig, PathUtil.getPathMapByApiCode("setSignalControl"),
                    JSON.toJSONString(param), null, null, "application/json", null);
            HKResponse hkResponse = JSONObject.parseObject(strResult, HKResponse.class);
            if (Objects.nonNull(hkResponse) && Objects.equals(HK_SUCCESS_STRING_CODE, hkResponse.getCode())) {
                return jsonViewObject.success("海康下发信号机控制成功");
            }
            return jsonViewObject.fail("海康下发信号机控制失败，".concat(hkResponse.getMsg()));
        } else {
            //return controlSignal(commandVO.getCrossCode(), UNLOCK_RUNNING_CONTROL);
            return controlSignal(signalCode, UNLOCK_RUNNING_CONTROL);
        }

    }

    /**
     * 获取某一路口下海康相位和车道关系
     *
     * @param crossCode 信号机唯一编号
     * @return {@link Map}<{@link Integer}, {@link JSONArray}> 相位与车道集合
     * @throws Exception 异常
     */
    private Map<Integer, JSONArray> getPhaseRelationLanes(String crossCode) throws Exception {
        Map<String, String> path = PathUtil.getPathMapByApiCode("getPhaseRlatLanes");
        Map<String, String> queryMap = new HashMap<>();
        queryMap.put("crossCode", crossCode);
        String strResult = ArtemisHttpUtil.doPostStringArtemis(artemisConfig, path, null, queryMap,
                null, "application/json", null);
        JSONObject obj = JSON.parseObject(strResult);
        Map<Integer, JSONArray> laneArrayMap = new HashMap<>();
        if (HK_SUCCESS_STRING_CODE.equals(obj.get(HK_CODE_KEY))) {
            JSONObject data = obj.getJSONObject("data");
            JSONArray phaseList = data.getJSONArray("phaseList");
            for (int i = 0; i < phaseList.size(); i++) {
                JSONObject lanesObject = phaseList.getJSONObject(i);
                Integer phaseNo = lanesObject.getInteger("phaseNo");
                JSONArray laneList = lanesObject.getJSONArray("lanes");
                // 存入相位与车道集合
                laneArrayMap.put(phaseNo, laneList);
            }
        } else {
            throw new ControlException(obj.getString("msg"));
        }
        return laneArrayMap;
    }

    @Override
    public JsonViewObject stepControl(String code, Integer command, Integer stepNum) throws Exception {
        JsonViewObject jsonViewObject = JsonViewObject.newInstance();
        CrossInfoPO crossInfoPO = crossInfoMapper.selectByPrimaryKey(code);
        if (Objects.isNull(crossInfoPO)) {
            return jsonViewObject.fail("当前路口编号有误，路口信息不存在");
        }
        String signalCode = crossInfoPO.getCode();
        if (command.equals(TRUE)) {

            Map<String, Object> param = new HashMap<>();
            param.put("crossCode", signalCode);
            param.put("controlType", STEP_CONTROL);

            int controlNo = 0;
            if (0 != stepNum) {
                //根据当前实时灯态获取运行的相位
                //LightsStatusVO lightsStatusVO = getSignalInfoVos(code).get(0);
                LightsStatusVO lightsStatusVO = getSignalInfoVos(signalCode).get(0);
                //暂时按单环处理
                String phaseId = lightsStatusVO.getPhaseId();
                //获取方案数据列表
                List<CrossPhasePO> baseCrossPhasePlanList = crossPhaseMapper.selectByCrossIdAndPlanId(lightsStatusVO.getCode(), lightsStatusVO.getPhasePlanId());
                Map<String, List<CrossPhasePO>> groupByPhase = baseCrossPhasePlanList.stream().collect(Collectors.groupingBy(CrossPhasePO::getPhaseNo));
                //根据相位获取当前相序
                int newPhaseOrderId = 0;
                for (String key : groupByPhase.keySet()) {
                    CrossPhasePO crossPhase = groupByPhase.get(key).get(0);
                    if (crossPhase.getPhaseNo().equals(phaseId)) {
                        newPhaseOrderId = (crossPhase.getSort() + stepNum) % groupByPhase.size();
                    }
                }
                //根据相序获取相位
                for (String key : groupByPhase.keySet()) {
                    CrossPhasePO crossPhase = groupByPhase.get(key).get(0);
                    if (newPhaseOrderId == crossPhase.getSort()) {
                        controlNo = Integer.parseInt(crossPhase.getPhaseNo());
                    }
                }
            }
            param.put("controlNo", controlNo);
            Map<String, String> controlPathMap = PathUtil.getPathMapByApiCode("setSignalControl");
            String strResult = ArtemisHttpUtil.doPostStringArtemis(artemisConfig, controlPathMap, JSON.toJSONString(param), null, null, "application/json", null);
            JSONObject obj = JSON.parseObject(strResult);
            if (HK_SUCCESS_STRING_CODE.equals(obj.get(HK_CODE_KEY))) {
                return jsonViewObject.success();
            }
            return jsonViewObject.fail(obj.getString("msg"));
        } else {
            return controlSignal(signalCode, CANCEL_STEP_CONTROL);
        }

    }

    @Override
    public JsonViewObject setSignalControl(String code, Integer command, Integer commandType) throws Exception {
        CrossInfoPO crossInfoPO = crossInfoMapper.selectByPrimaryKey(code);
        Integer runningMode = command.equals(TRUE) ? commandType : NORMAL_RUNNING_CONTROL;
        return controlSignal(crossInfoPO.getCode(), runningMode);
    }

    @Override
    public JsonViewObject recoverSchedule(String code) throws Exception {
        CrossInfoPO crossInfoPO = crossInfoMapper.selectByPrimaryKey(code);
        return controlSignal(crossInfoPO.getCode(), NORMAL_RUNNING_CONTROL);
    }

    @Override
    public JsonViewObject phaseTimingSend(PhaseTimingSendVO phaseTimingSendVO) throws Exception {
        JsonViewObject jsonViewObject = JsonViewObject.newInstance();
        CrossInfoPO crossInfoPO = crossInfoMapper.selectByPrimaryKey(phaseTimingSendVO.getCrossCode());
        if (Objects.isNull(crossInfoPO)) {
            return jsonViewObject.fail("当前路口编号有误，路口信息不存在");
        }
        String signalCode = crossInfoPO.getCode();
        // 将路口code转换为信号机code
        phaseTimingSendVO.setCrossCode(signalCode);
        Map<String, Object> param = FieldUtil.fieldMethod(phaseTimingSendVO);
        Map<String, String> path = PathUtil.getPathMapByApiCode("setPhaseRlatLanes");
        String strResult = ArtemisHttpUtil.doPostStringArtemis(artemisConfig, path, JSON.toJSONString(param), null, null, "application/json", null);
        JSONObject obj = JSON.parseObject(strResult);
        if (HK_SUCCESS_STRING_CODE.equals(obj.get(HK_CODE_KEY))) {
            return jsonViewObject.success();
        }
        return jsonViewObject.fail(obj.getString("msg"));
    }

    @Override
    public JsonViewObject phaseDiffSend() {
        return null;
    }

    /**
     * @param code        信号机编号
     * @param runningMode 0-多时段控制模式 1-关灯、2-黄闪、3-全红、11-取消步进控制、12-灯态锁定、13-灯态解锁
     */
    private JsonViewObject controlSignal(String code, Integer runningMode) throws Exception {
        JsonViewObject jsonViewObject = JsonViewObject.newInstance();
        //执行恢复时间表方案命令
        if (NORMAL_RUNNING_CONTROL.equals(runningMode) || CANCEL_STEP_CONTROL.equals(runningMode)) {
            //根据实时灯态获取当前运行模式
            List<BaseCrossInfo> baseSignals = new ArrayList<>();
            BaseCrossInfo baseSignal = new BaseCrossInfo();
            baseSignal.setCode(code);
            baseSignal.setManufacturerCode(BasicEnum.ManufacturerEnum.HK.getCode());
            baseSignals.add(baseSignal);
            LightsStatusVO lightsStatusVO = hkLightsStatusService.getHkLightsStatus(baseSignals).get(0);
            //如果当前模式已经是定周期，就不在执行恢复时间表方案指令
//            if (FIXED_CYCLE_MODE.equals(Integer.valueOf(lightsStatusVO.getRunMode()))) {
//                throw new ControlException("当前控制模式是定周期控制，请勿下发恢复命令");
//            }
        }
        Map<String, Object> param = new HashMap<>();
        param.put("crossCode", code);
        param.put("controlType", runningMode);
        param.put("controlNo", 0);
        //控制时长，单位 s，0 则持续控制
        param.put("duration", 0);

        String strResult = ArtemisHttpUtil.doPostStringArtemis(artemisConfig, PathUtil.getPathMapByApiCode("setSignalControl"), JSON.toJSONString(param), null, null, "application/json", null);
        HKResponse hkResponse = JSONObject.parseObject(strResult, HKResponse.class);
        if (Objects.nonNull(hkResponse) && Objects.equals(HK_SUCCESS_STRING_CODE, hkResponse.getCode())) {
            return jsonViewObject.success("海康下发信号机控制成功");
        }
        return jsonViewObject.fail("海康下发信号机控制失败，".concat(hkResponse.getMsg()));
    }

    /**
     * 根据信号机获取灯态列表
     */
    private List<LightsStatusVO> getSignalInfoVos(String code) {
        List<BaseCrossInfo> baseSignals = new ArrayList<>();
        BaseCrossInfo baseSignal = new BaseCrossInfo();
        baseSignal.setCode(code);
        baseSignal.setManufacturerCode(BasicEnum.ManufacturerEnum.HK.getCode());
        baseSignals.add(baseSignal);
        return hkLightsStatusService.getHkLightsStatus(baseSignals);
    }

    /**
     * 通用方法-检查路口id
     * 查询出信号机id
     */
    private ManufacturerInfoPO checkCrossCode(String crossCode) {
        // 根据路口id查询
        CrossInfoPO crossInfoPo = crossInfoMapper.selectByPrimaryKey(crossCode);
        if (crossInfoPo == null) {
            throw new ControlException(BODY_NOT_MATCH.getResultCode(), "参数错误，路口ID不正确。");
        }
        // 厂商 HK
        ManufacturerInfoPO manufacturerInfoPO = manufacturerInfoMapper.selectById(crossInfoPo.getManufacturerId());
        // 路口code不是信号机code，此处为了方便，利用ManufacturerInfoPO的name属性做一下存储
        manufacturerInfoPO.setName(crossInfoPo.getCode());
        return manufacturerInfoPO;
    }
}
